| Title: | Natural Logarithms of the Gamma Function for Large Values |
|---|---|
| Description: | Uses approximations to compute the natural logarithm of the Gamma function for large values. |
| Authors: | Phillip Labuschagne <[email protected]> |
| Maintainer: | Phillip Labuschagne <[email protected]> |
| License: | GPL-3 |
| Version: | 0.0.1 |
| Built: | 2026-05-17 09:01:05 UTC |
| Source: | https://github.com/philliplab/logofgamma |
For values larger than 12, an approximation is used.
gammaln(x)gammaln(x)
x |
A numeric vector of positive numbers. |
gammaln(5) gammaln(50)gammaln(5) gammaln(50)
Uses the approximation in Hart et al, Computer Approximations 1968.
gammaln_internal(x)gammaln_internal(x)
x |
A numeric value of length 1 greater than 12 |
gammaln_internal(50)gammaln_internal(50)