Welcome to ClientVPS Mirrors

Help for package logOfGamma
Title: Natural Logarithms of the Gamma Function for Large Values
Description: Uses approximations to compute the natural logarithm of the Gamma function for large values.
Version: 0.0.1
Author: Phillip Labuschagne <philliplab@gmail.com>
Maintainer: Phillip Labuschagne <philliplab@gmail.com>
Suggests: testthat
License: GPL-3
RoxygenNote: 5.0.1
NeedsCompilation: no
Packaged: 2017-06-01 17:02:03 UTC; phillipl
Repository: CRAN
Date/Publication: 2017-06-02 06:26:03 UTC

Computes the natural logarithm of the gamma function.

Description

For values larger than 12, an approximation is used.

Usage

gammaln(x)

Arguments

x

A numeric vector of positive numbers.

Examples

gammaln(5)
gammaln(50)

Computes the natural logarithm of the gamma function for values larger than 12.

Description

Uses the approximation in Hart et al, Computer Approximations 1968.

Usage

gammaln_internal(x)

Arguments

x

A numeric value of length 1 greater than 12

Examples

gammaln_internal(50)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.